import * as cdk from '@aws-cdk/core';
/**
 * The databaseUsers resource lets you retrieve, create and modify the MongoDB users in your cluster.
 *
 * Each user has a set of roles that provide access to the project’s databases. A user’s roles apply to all the clusters in the project: if two clusters have a products database and a user has a role granting read access on the products database, the user has that access on both clusters.
 *
 * @schema CfnDatabaseUserProps
 */
export interface CfnDatabaseUserProps {
    /**
     * If this value is set, the new database user authenticates with AWS IAM credentials.
     *
     * @schema CfnDatabaseUserProps#AWSIAMType
     */
    readonly awsiamType?: CfnDatabaseUserPropsAwsiamType;
    /**
     * @schema CfnDatabaseUserProps#ApiKeys
     */
    readonly apiKeys?: ApiKeyDefinition;
    /**
     * The user’s authentication database.
     *
     * A user must provide both a username and authentication database to log into MongoDB. In Atlas deployments of MongoDB, the authentication database is always the admin database.
     *
     * @schema CfnDatabaseUserProps#DatabaseName
     */
    readonly databaseName: string;
    /**
     * Array containing key-value pairs that tag and categorize the database user.
     *
     * @schema CfnDatabaseUserProps#Labels
     */
    readonly labels?: LabelDefinition[];
    /**
     * Method by which the provided username is authenticated.
     *
     * If no value is given, Atlas uses the default value of NONE.
     *
     * @schema CfnDatabaseUserProps#LdapAuthType
     */
    readonly ldapAuthType?: CfnDatabaseUserPropsLdapAuthType;
    /**
     * The user’s password.
     *
     * This field is not included in the entity returned from the server.
     *
     * @schema CfnDatabaseUserProps#Password
     */
    readonly password?: string;
    /**
     * Unique identifier of the Atlas project to which the user belongs.
     *
     * @schema CfnDatabaseUserProps#ProjectId
     */
    readonly projectId: string;
    /**
     * Array of this user’s roles and the databases / collections on which the roles apply.
     *
     * A role allows the user to perform particular actions on the specified database. A role on the admin database can include privileges that apply to the other databases as well.
     *
     * @schema CfnDatabaseUserProps#Roles
     */
    readonly roles: RoleDefinition[];
    /**
     * Array of clusters and Atlas Data Lakes that this user has access to.
     *
     * If omitted, Atlas grants the user access to all the clusters and Atlas Data Lakes in the project by default.
     *
     * @schema CfnDatabaseUserProps#Scopes
     */
    readonly scopes?: ScopeDefinition[];
    /**
     * Username for authenticating to MongoDB.
     *
     * @schema CfnDatabaseUserProps#Username
     */
    readonly username: string;
}
/**
 * Converts an object of type 'CfnDatabaseUserProps' to JSON representation.
 */
export declare function toJson_CfnDatabaseUserProps(obj: CfnDatabaseUserProps | undefined): Record<string, any> | undefined;
/**
 * If this value is set, the new database user authenticates with AWS IAM credentials.
 *
 * @schema CfnDatabaseUserPropsAwsiamType
 */
export declare enum CfnDatabaseUserPropsAwsiamType {
    /**
     * NONE.
     */
    NONE = "NONE",
    /**
     * USER.
     */
    USER = "USER",
    /**
     * ROLE.
     */
    ROLE = "ROLE"
}
/**
 * @schema apiKeyDefinition
 */
export interface ApiKeyDefinition {
    /**
     * @schema apiKeyDefinition#PrivateKey
     */
    readonly privateKey?: string;
    /**
     * @schema apiKeyDefinition#PublicKey
     */
    readonly publicKey?: string;
}
/**
 * Converts an object of type 'ApiKeyDefinition' to JSON representation.
 */
export declare function toJson_ApiKeyDefinition(obj: ApiKeyDefinition | undefined): Record<string, any> | undefined;
/**
 * @schema labelDefinition
 */
export interface LabelDefinition {
    /**
     * @schema labelDefinition#Key
     */
    readonly key?: string;
    /**
     * @schema labelDefinition#Value
     */
    readonly value?: string;
}
/**
 * Converts an object of type 'LabelDefinition' to JSON representation.
 */
export declare function toJson_LabelDefinition(obj: LabelDefinition | undefined): Record<string, any> | undefined;
/**
 * Method by which the provided username is authenticated.
 *
 * If no value is given, Atlas uses the default value of NONE.
 *
 * @schema CfnDatabaseUserPropsLdapAuthType
 */
export declare enum CfnDatabaseUserPropsLdapAuthType {
    /**
     * NONE.
     */
    NONE = "NONE",
    /**
     * USER.
     */
    USER = "USER",
    /**
     * GROUP.
     */
    GROUP = "GROUP"
}
/**
 * @schema roleDefinition
 */
export interface RoleDefinition {
    /**
     * @schema roleDefinition#CollectionName
     */
    readonly collectionName?: string;
    /**
     * @schema roleDefinition#DatabaseName
     */
    readonly databaseName?: string;
    /**
     * @schema roleDefinition#RoleName
     */
    readonly roleName?: string;
}
/**
 * Converts an object of type 'RoleDefinition' to JSON representation.
 */
export declare function toJson_RoleDefinition(obj: RoleDefinition | undefined): Record<string, any> | undefined;
/**
 * @schema scopeDefinition
 */
export interface ScopeDefinition {
    /**
     * @schema scopeDefinition#Name
     */
    readonly name?: string;
    /**
     * @schema scopeDefinition#Type
     */
    readonly type?: ScopeDefinitionType;
}
/**
 * Converts an object of type 'ScopeDefinition' to JSON representation.
 */
export declare function toJson_ScopeDefinition(obj: ScopeDefinition | undefined): Record<string, any> | undefined;
/**
 * @schema ScopeDefinitionType
 */
export declare enum ScopeDefinitionType {
    /**
     * CLUSTER.
     */
    CLUSTER = "CLUSTER",
    /**
     * DATA_LAKE.
     */
    DATA_LAKE = "DATA_LAKE"
}
/**
 * A CloudFormation `MongoDB::Atlas::DatabaseUser`.
 *
 * @external
 * @cloudformationResource MongoDB::Atlas::DatabaseUser
 * @link http://unknown-url
 */
export declare class CfnDatabaseUser extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     *
     * @external
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "MongoDB::Atlas::DatabaseUser";
    /**
     * Resource props.
     *
     * @external
     */
    readonly props: CfnDatabaseUserProps;
    /**
     * Attribute `MongoDB::Atlas::DatabaseUser.UserCFNIdentifier`.
     *
     * @external
     * @link http://unknown-url
     */
    readonly attrUserCFNIdentifier: string;
    /**
     * Create a new `MongoDB::Atlas::DatabaseUser`.
     *
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     * @external
     */
    constructor(scope: cdk.Construct, id: string, props: CfnDatabaseUserProps);
}
